@@ -12,7 +12,7 @@ function j2sdk_control() {
 Package: $j2se_package
 Architecture: any
 Depends: \${shlibs:Depends}
-Recommends: netbase, libx11-6 | xlibs, libasound2, libgtk1.2
+Recommends: netbase, libx11-6 | xlibs, libasound2, libgtk1.2, libstdc++5
 Provides: java-virtual-machine, java-runtime, java2-runtime, java-browser-plugin, java-compiler, java2-compiler, j2sdk$j2se_release, j2re$j2se_release
 Replaces: ${j2se_package}debian
 Description: $j2se_title
