@@ -6,32 +6,42 @@ function sun_j2re_detect() {
     i386|i486-linux-gnu)
       case "$archive_name" in
 	"j2re-1_4_1_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
-	    j2se_version="1.4.1+${archive_name:11:2}"
+	    j2se_version="1.4.1+${archive_name:11:2}${revision}"
 	    j2se_expected_min_size=14 # 14378891 bytes
 	    found=true
 	    ;;
 	"j2re-1_4_2-linux-i586.bin") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=14 # 14378891 bytes
 	    found=true
 	    ;;
 	"j2re-1_4_2_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
-	    j2se_version="1.4.2+${archive_name:11:2}"
+	    j2se_version="1.4.2+${archive_name:11:2}${revision}"
 	    j2se_expected_min_size=15 # 14378891 bytes
 	    found=true
 	    ;;
 	"j2re-1_5_0-beta2-linux-i586.bin") # SUPPORTED
-	    j2se_version=1.5.0+beta2
+	    j2se_version=1.5.0+beta2${revision}
 	    j2se_expected_min_size=16 # 16542512 bytes
 	    found=true
 	    ;;
 	"jre-1_5_0-linux-i586.bin") # SUPPORTED
-	    j2se_version=1.5.0+update00
+	    j2se_version=1.5.0+update00${revision}
 	    j2se_expected_min_size=16 # 16542512 bytes
 	    found=true
 	    ;;
 	"jre-1_5_0_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
-	    j2se_version=1.5.0+update${archive_name:10:2}
+	    j2se_version=1.5.0+update${archive_name:10:2}${revision}
+	    j2se_expected_min_size=16 # 16542512 bytes
+	    found=true
+	    ;;
+	"jre-6-linux-i586.bin") # SUPPORTED
+	    j2se_version=1.6.0${revision}
+	    j2se_expected_min_size=16 # 16542512 bytes
+	    found=true
+	    ;;
+	"jre-6u"[0-9]"-linux-i586.bin") # SUPPORTED
+	    j2se_version=1.6.0+update${archive_name:6:1}${revision}
 	    j2se_expected_min_size=16 # 16542512 bytes
 	    found=true
 	    ;;
@@ -40,15 +50,20 @@ function sun_j2re_detect() {
     amd64|x86_64-linux-gnu)
       case "$archive_name" in
 	"jre-1_5_0-linux-amd64.bin") # SUPPORTED
-	    j2se_version=1.5.0+update00
+	    j2se_version=1.5.0+update00${revision}
 	    j2se_expected_min_size=65 # 69936 kB
 	    found=true
 	    ;;
 	"jre-1_5_0_"[0-9][0-9]"-linux-amd64.bin") # SUPPORTED
-	    j2se_version=1.5.0+update${archive_name:10:2}
+	    j2se_version=1.5.0+update${archive_name:10:2}${revision}
 	    j2se_expected_min_size=60 # 69936 kB
 	    found=true
 	    ;;
+	"jre-6u"[0-9]"-linux-amd64.bin") # SUPPORTED
+	    j2se_version=1.6.0+update${archive_name:6:1}${revision}
+	    j2se_expected_min_size=16 # 16542512 bytes
+	    found=true
+	    ;;
       esac
       ;;
   esac
